package com.gic.haoban.manage.api.service;

import com.gic.api.base.commons.JSONResponse;
import com.gic.api.base.commons.Page;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.base.api.common.ServiceResponse;
import com.gic.haoban.manage.api.dto.*;

import java.util.Date;
import java.util.List;

public interface MemberUnionidRelatedApiService {

    /**
     * 根据导购导购微信id和会员id查询关联关系
     *
     * @param wxUserId : 导购微信id
     * @param memberId : 会员id
     * @return : 返回导购与会员关联关系
     */
    ExternalClerkRelatedDTO getByWxUserIdMemberId(String staffId, String memberId);

    /**
     * 外部联系人新增（加好友）
     *
     * @param dto
     * @return
     */
    String addMemberUnionidRelated(MemberUnionidRelatedDTO dto);

    /**
     * 外部联系人删除（删好友）
     *
     * @param dto
     */
    void delMemberUnionidRelated(MemberUnionidRelatedDTO dto);

    /**
     * 外部联系人新增（修改好友）
     *
     * @param dto
     */
    void editMemberUnionidRelated(MemberUnionidRelatedDTO dto);

    /**
     * 处理外部联系人异步
     * "routerName": "dealQywxExternalUserMq"
     *
     * @param params
     */
    void dealQywxExternalUser(String params);

    ExternalClerkRelatedDTO getByMemberId(String staffId, String memberId);

    /**
     * 查看是否可以跳转会员详情的会员列表
     *
     * @param externalUserid
     * @param wxUserId
     * @param storeId
     * @return
     */
    List<MemberStoreDTO> listByExTernalUseridAndWxUserId(String externalUserid, String wxUserId, String storeId);

    void cleanByCid(String cid);

    /**
     * 群发助手发送企业微信消息
     *
     * @param wxEnterpriseId
     * @param userId
     * @param extendUserList
     * @param materialId
     * @return {@link String }
     * @author mozhu
     * @date 2022-01-13 10:50:44
     */
    String sendMessage(String wxEnterpriseId, String userId, List<String> extendUserList, String materialId);

    /**
     * 创建企业群发, 支出素材批量发送
     *
     * @param wxEnterpriseId : 微信企业id
     * @param userId         : 用户id
     * @param extendUserList : 发送的用户id
     * @param materialIdList : 素材id列表
     * @return : 返回群发执行结果
     */
    JSONResponse sendMessage(String wxEnterpriseId, String userId, List<String> extendUserList, List<String> materialIdList);

    /**
     * 获取群发成员发送任务列表
     *
     * @param wxEnterpriseId : 微信企业id
     * @param wxMessageId    : 消息id
     * @param cursor         : 分页游标
     * @return : 返回请求结果
     */
    JSONResponse taskExternalMessage(String wxEnterpriseId, String wxMessageId, String cursor);

    /**
     * 获取企业群发成员执行结果
     *
     * @param wxEnterpriseId : 微信企业id
     * @param wxMessageId    : 消息id
     * @param cursor         : 分页游标
     * @param userId         : 用户id
     * @return : 返回请求结果
     */
    JSONResponse resultExternalMessage(String wxEnterpriseId, String wxMessageId, String cursor, String userId);

    JSONResponse getMessageStatus(String wxEnterpriseId, String wxMessageId);

    /**
     * 添加好友
     *
     * @param dto dto
     * @return {@link String }
     * @author mozhu
     * @date 2021-12-13 17:12:39
     */
    String addMemberUnionidRelatedNew(MemberUnionidRelatedDTO dto);

    /**
     * 客户列表-自建
     *
     * @param wxEnterpriseId
     * @param wxUserId
     * @return
     */
    List<String> listSelfExterialList(String wxEnterpriseId, String wxUserId);

    /**
     * 客户详情-第三方
     *
     * @param wxEnterpriseId
     * @param wxUserId
     * @return
     */
    List<String> listExterialList(String wxEnterpriseId, String wxUserId);

    /**
     * 客户详情-自建
     *
     * @param wxEnterpriseId
     * @param wxUserId
     * @param externalUserId
     * @return
     */
    ExternalUserDTO getCorpSelfExternalUseridInfo(String wxEnterpriseId, String wxUserId, String externalUserId);

    /**
     * 添加企微好友关联关系表-无需触达
     *
     * @param dto
     * @return
     */
    String addExternal(ExternalUserDTO dto);

    /**
     * 添加企微好友关联关系表-需触达方式
     *
     * @param dto
     * @return
     */
    String addFriendExternal(ExternalUserDTO dto);

    /**
     * 获取客户详情-第三方
     *
     * @param wxEnterpriseId
     * @param wxUserId
     * @param externalUserId
     * @return
     */
    ExternalUserDTO getExternalUseridInfo(String wxEnterpriseId, String wxUserId, String externalUserId);

    /**
     * 清理外部联系人
     *
     * @param wxEnterpriseId
     * @param wxUserId
     * @param externalUserIds
     */
    void cleanNoExsitFriendNew(String wxEnterpriseId, String staffId, List<String> externalUserIds);

    /**
     * 根据会员的unionid 获取好友导购列表
     *
     * @param enterpriseId
     * @param unionId
     * @return
     */
    ServiceResponse<List<FriendStoreInfoDTO>> listFriendClerkByMemberUnionid(String enterpriseId, String unionId);


    /**
     * 根据企业内部外部联系人id 获取关联关系
     *
     * @param wxEnterpriseId     wx企业标识
     * @param selfExternalUserId 自外部的用户id
     * @return {@link MemberUnionidRelatedDTO }
     * @author mozhu
     * @date 2021-12-23 22:39:25
     */
    MemberUnionidRelatedDTO getBySelfExternalUserId(String wxEnterpriseId, String selfExternalUserId);


    /**
     * 关注公共号-会员回调好办关联好友（通过查询unionid关联导购对外联系人id接口）
     * "routerName"：addMemberUnionidWechatAccountMq
     *
     * @param res res
     * @author mozhu
     * @date 2022-01-22 16:59:25
     */
    void addMemberUnionidWechatAccount(String res);


    /**
     * 关注公共号-会员回调好办关联好友（通过公共号二维码带参数）
     * "routerName"：addMemberUnionidWechatAccountByClerkMq
     *
     * @param res res
     * @author mozhu
     * @date 2022-02-21 14:56:25
     */
    void addMemberUnionidWechatAccountByClerk(String res);


    /**
     * 根据id查询
     *
     * @param memberUnionidRelatedId 成员unionid相关id
     * @return {@link MemberUnionidRelatedDTO }
     * @author mozhu
     * @date 2022-03-11 17:02:45
     */
    MemberUnionidRelatedDTO getById(String memberUnionidRelatedId);


    /**
     * 更新对外联系人id
     *
     * @param selfExternalUserid     自外部用户标识
     * @param memberUnionidRelatedId 成员unionid相关id
     * @author mozhu
     * @date 2022-03-11 16:59:24
     */
    void updateSelfExternalUseridById(String selfExternalUserid, String memberUnionidRelatedId);

    /**
     * 更新新userid corpid
     *
     * @param wxEnterpriseId wx企业标识
     * @return {@link ServiceResponse }
     * @author mozhu
     * @date 2022-06-30 13:54:12
     */
    ServiceResponse updateNewUseridCorpid(String wxEnterpriseId);


    /**
     * 更新新userid corpid mq
     * "routerName": "updateNewUseridCorpidMq"
     *
     * @param params 参数个数
     * @author mozhu
     * @date 2022-06-30 13:56:27
     */
    void updateNewUseridCorpidMq(String params);


}
